@@ -132,7 +132,7 @@ if(!(3%in%dev.list())) dev.new()
  # Is there a Tk window already open ?
 if(interactive())
 {
- if(!exists("GeoXp.open",envir = baseenv())||length(ls(envir=.TkRoot$env, all=TRUE))==2)
+ if(!exists("GeoXp.open",envir = baseenv())||length(ls(envir=.TkRoot$env, all.names=TRUE))==2)
  {
   assign("GeoXp.open", TRUE, envir = baseenv())
  }
